pub struct RecordBatchDecoder<'a> { /* private fields */ }Expand description
State for decoding Arrow arrays from an IPC RecordBatch structure to
RecordBatch
Implementations
Sourceimpl<'a> RecordBatchDecoder<'a>
impl<'a> RecordBatchDecoder<'a>
Sourcepub fn with_projection(
self,
projection: Option<&'a [usize]>,
) -> RecordBatchDecoder<'a>
pub fn with_projection( self, projection: Option<&'a [usize]>, ) -> RecordBatchDecoder<'a>
Set the projection (default: None)
If set, the projection is the list of column indices that will be read
Sourcepub fn with_require_alignment(
self,
require_alignment: bool,
) -> RecordBatchDecoder<'a>
pub fn with_require_alignment( self, require_alignment: bool, ) -> RecordBatchDecoder<'a>
Set require_alignment (default: false)
If true, buffers must be aligned appropriately or error will result. If false, buffers will be copied to aligned buffers if necessary.