JsonReadOptions

Struct JsonReadOptions 

pub struct JsonReadOptions<'a> {
    pub schema: Option<&'a Schema>,
    pub schema_infer_max_records: usize,
    pub file_extension: &'a str,
    pub table_partition_cols: Vec<(String, DataType)>,
    pub file_compression_type: FileCompressionType,
    pub infinite: bool,
    pub file_sort_order: Vec<Vec<SortExpr>>,
    pub newline_delimited: bool,
}
Options that control the reading of JSON files.

Supports both newline-delimited JSON (NDJSON) and JSON array formats.

Note this structure is supplied when a datasource is created and can not vary from statement to statement. For settings that can vary statement to statement see ConfigOptions.

Fields

schema: Option<&'a Schema>

The data source schema.

schema_infer_max_records: usize

Max number of rows to read from JSON files for schema inference if needed. Defaults to DEFAULT_SCHEMA_INFER_MAX_RECORD.

file_extension: &'a str

File extension; only files with this extension are selected for data input. Defaults to FileType::JSON.get_ext().as_str().

table_partition_cols: Vec<(String, DataType)>

Partition Columns

file_compression_type: FileCompressionType

File compression type

infinite: bool

Flag indicating whether this file may be unbounded (as in a FIFO file).

file_sort_order: Vec<Vec<SortExpr>>

Indicates how the file is sorted

newline_delimited: bool

Whether to read as newline-delimited JSON (default: true).

When true (default), expects newline-delimited JSON (NDJSON):

{"key1": 1, "key2": "val"}
{"key1": 2, "key2": "vals"}

When false, expects JSON array format:

[
  {"key1": 1, "key2": "val"},
  {"key1": 2, "key2": "vals"}
]

Implementations

Source

impl<'a> JsonReadOptions<'a>

pub fn table_partition_cols( self, table_partition_cols: Vec<(String, DataType)>, ) -> Self

Specify table_partition_cols for partition pruning

pub fn file_extension(self, file_extension: &'a str) -> Self

Specify file_extension

pub fn mark_infinite(self, infinite: bool) -> Self

Configure mark_infinite setting

pub fn file_compression_type( self, file_compression_type: FileCompressionType, ) -> Self

Specify file_compression_type

pub fn schema(self, schema: &'a Schema) -> Self

Specify schema to use for NdJson read

pub fn file_sort_order(self, file_sort_order: Vec<Vec<SortExpr>>) -> Self

Configure if file has known sort order

pub fn schema_infer_max_records(self, schema_infer_max_records: usize) -> Self

Specify how many rows to read for schema inference

pub fn newline_delimited(self, newline_delimited: bool) -> Self

Set whether to read as newline-delimited JSON.

When true (default), expects newline-delimited JSON (NDJSON):

{"key1": 1, "key2": "val"}
{"key1": 2, "key2": "vals"}

When false, expects JSON array format:

[
  {"key1": 1, "key2": "val"},
  {"key1": 2, "key2": "vals"}
]