pub struct PartitionedFile {
    pub object_meta: ObjectMeta,
    pub partition_values: Vec<ScalarValue>,
    pub range: Option<FileRange>,
    pub extensions: Option<Arc<dyn Any + Send + Sync>>,
}
A single file or part of a file that should be read, along with its schema, statistics and partition column values that need to be appended to each row.

Fields

object_meta: ObjectMeta

Path for the file (e.g. URL, filesystem path, etc)

partition_values: Vec<ScalarValue>

Values of partition columns to be appended to each row.

These MUST have the same count, order, and type than the table_partition_cols.

You may use wrap_partition_value_in_dict to wrap them if you have used wrap_partition_type_in_dict to wrap the column type.

range: Option<FileRange>

An optional file range for a more fine-grained parallel execution

extensions: Option<Arc<dyn Any + Send + Sync>>

An optional field for user defined per object metadata

Implementations

source

impl PartitionedFile

source

pub fn new(path: impl Into<String>, size: u64) -> Self

Create a simple file without metadata or partition

source

pub fn new_with_range(path: String, size: u64, start: i64, end: i64) -> Self

Create a file range without metadata or partition

source

pub fn from_path(path: String) -> Result<Self>

Return a file reference from the given path

source

pub fn path(&self) -> &Path

Return the path of this partitioned file

source

pub fn with_range(self, start: i64, end: i64) -> Self

Update the file to only scan the specified range (in bytes)