Struct datafusion::datasource::physical_plan::CsvExec
source · pub struct CsvExec {
pub file_compression_type: FileCompressionType,
/* private fields */
}Expand description
Execution plan for scanning a CSV file
Fields
file_compression_type: FileCompressionTypeCompression type of the file associated with CsvExec
Implementations
sourceimpl CsvExec
impl CsvExec
sourcepub fn new(
base_config: FileScanConfig,
has_header: bool,
delimiter: u8,
quote: u8,
escape: Option<u8>,
file_compression_type: FileCompressionType
) -> Self
pub fn new( base_config: FileScanConfig, has_header: bool, delimiter: u8, quote: u8, escape: Option<u8>, file_compression_type: FileCompressionType ) -> Self
Create a new CSV reader execution plan provided base and specific configurations
sourcepub fn base_config(&self) -> &FileScanConfig
pub fn base_config(&self) -> &FileScanConfig
Ref to the base configs
sourcepub fn has_header(&self) -> bool
pub fn has_header(&self) -> bool
true if the first line of each file is a header