Module to_local_time

Module to_local_time 

Available on crate feature datetime_expressions only.

Structs

ToLocalTimeFunc
A UDF function that converts a timezone-aware timestamp to local time (with no offset or timezone information). In other words, this function strips off the timezone from the timestamp, while keep the display value of the timestamp the same.

Functions

adjust_to_local_time
This function converts a timestamp with a timezone to a timestamp without a timezone. The display value of the adjusted timestamp remain the same, but the underlying timestamp representation is adjusted according to the relative timezone offset to UTC.