pub fn array_except(first_array: Expr, second_array: Expr) -> ExprAvailable on crate feature
nested_expressions only.Expand description
returns an array of the elements that appear in the first array but not in the second.