pub fn map_extract(map: Expr, key: Expr) -> ExprAvailable on crate feature
nested_expressions only.Expand description
Return a list containing the value for a given key or an empty list if the key is not contained in the map.