pub enum FunctionArguments {
None,
Subquery(Box<Query>),
List(FunctionArgumentList),
}Expand description
The arguments passed to a function call.
Variants
None
Used for special functions like CURRENT_TIMESTAMP that are invoked
without parentheses.
Subquery(Box<Query>)
On some dialects, a subquery can be passed without surrounding parentheses if it’s the sole argument to the function.
List(FunctionArgumentList)
A normal function argument list, including any clauses within it such as
DISTINCT or ORDER BY.