Interval arithmetic and constraint propagation library

Modules

  • Constraint propagator/solver for custom PhysicalExpr graphs.
  • Interval arithmetic library
  • Floating point rounding mode utility library TODO: Remove this custom implementation and the “libc” dependency when floating-point rounding mode manipulation functions become available in Rust.
  • Test utilities for the interval arithmetic library
  • Utility functions for the interval arithmetic library

Structs

  • This object implements a directed acyclic expression graph (DAEG) that is used to compute ranges for expressions through interval arithmetic.
  • This type represents an interval, which is used to calculate reliable bounds for expressions. Currently, we only support addition and subtraction, but more capabilities will be added in the future. Upper/lower bounds having NULL values indicate an unbounded side. For example; [10, 20], [10, ∞), (-∞, 100] and (-∞, ∞) are all valid intervals.
  • This type represents a single endpoint of an Interval. An endpoint can be open (does not include the endpoint) or closed (includes the endpoint).

Enums

Functions