Module physical_expr_adapter

Module physical_expr_adapter 

Modules

schema_rewriter
Physical expression schema rewriting utilities: PhysicalExprAdapter, PhysicalExprAdapterFactory, default implementations, and replace_columns_with_literals.

Structs

BatchAdapter
Adapter for transforming record batches to match a target schema.
BatchAdapterFactory
Factory for creating BatchAdapter instances to adapt record batches to a target schema.
DefaultPhysicalExprAdapter
Default implementation of PhysicalExprAdapter for rewriting physical expressions to match different schemas.
DefaultPhysicalExprAdapterFactory

Traits

PhysicalExprAdapter
Trait for adapting PhysicalExpr expressions to match a target schema.
PhysicalExprAdapterFactory
Creates instances of PhysicalExprAdapter for given logical and physical schemas.

Functions

replace_columns_with_literals
Replace column references in the given physical expression with literal values.