pub struct CoalesceBatchesExec { /* private fields */ }Expand description
CoalesceBatchesExec combines small batches into larger batches for more efficient use of vectorized processing by upstream operators.
Implementations
sourceimpl CoalesceBatchesExec
impl CoalesceBatchesExec
sourcepub fn new(
input: Arc<dyn ExecutionPlan>,
target_batch_size: usize
) -> CoalesceBatchesExec
pub fn new( input: Arc<dyn ExecutionPlan>, target_batch_size: usize ) -> CoalesceBatchesExec
Create a new CoalesceBatchesExec
sourcepub fn input(&self) -> &Arc<dyn ExecutionPlan>
pub fn input(&self) -> &Arc<dyn ExecutionPlan>
The input plan
sourcepub fn target_batch_size(&self) -> usize
pub fn target_batch_size(&self) -> usize
Minimum number of rows for coalesces batches