pub enum FunctionArgumentClause {
IgnoreOrRespectNulls(NullTreatment),
OrderBy(Vec<OrderByExpr>),
Limit(Expr),
OnOverflow(ListAggOnOverflow),
Having(HavingBound),
Separator(Value),
JsonNullClause(JsonNullClause),
JsonReturningClause(JsonReturningClause),
}Available on crate feature
sql only.Variants
IgnoreOrRespectNulls(NullTreatment)
Indicates how NULLs should be handled in the calculation, e.g. in FIRST_VALUE on BigQuery.
Syntax:
{ IGNORE | RESPECT } NULLS ]OrderBy(Vec<OrderByExpr>)
Specifies the the ordering for some ordered set aggregates, e.g. ARRAY_AGG on BigQuery.
Limit(Expr)
Specifies a limit for the ARRAY_AGG and ARRAY_CONCAT_AGG functions on BigQuery.
OnOverflow(ListAggOnOverflow)
Specifies the behavior on overflow of the LISTAGG function.
Having(HavingBound)
Specifies a minimum or maximum bound on the input to ANY_VALUE on BigQuery.
Syntax:
HAVING { MAX | MIN } expressionSeparator(Value)
The SEPARATOR clause to the GROUP_CONCAT function in MySQL.
JsonNullClause(JsonNullClause)
The ON NULL clause for some JSON functions.
MSSQL JSON_ARRAY
MSSQL JSON_OBJECT
PostgreSQL JSON functions
JsonReturningClause(JsonReturningClause)
The RETURNING clause for some JSON functions in PostgreSQL