pub enum IdentityPropertyFormatKind {
FunctionCall(IdentityParameters),
StartAndIncrement(IdentityParameters),
}Available on crate feature
sql only.Expand description
A format of parameters of identity column.
It is Snowflake specific. Syntax
(seed , increment) | START num INCREMENT numMS SQL Server uses one way of representing these parameters. Syntax
(seed , increment)Variants
FunctionCall(IdentityParameters)
A parameters of identity column declared like parameters of function call Example:
(100, 1)StartAndIncrement(IdentityParameters)
A parameters of identity column declared with keywords START and INCREMENT
Example:
START 100 INCREMENT 1Trait Implementations
Sourceimpl Clone for IdentityPropertyFormatKind
impl Clone for IdentityPropertyFormatKind
Sourcefn clone(&self) -> IdentityPropertyFormatKind
fn clone(&self) -> IdentityPropertyFormatKind
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentityPropertyFormatKind
impl Debug for IdentityPropertyFormatKind
Sourceimpl Display for IdentityPropertyFormatKind
impl Display for IdentityPropertyFormatKind
Sourceimpl Hash for IdentityPropertyFormatKind
impl Hash for IdentityPropertyFormatKind
Sourceimpl Ord for IdentityPropertyFormatKind
impl Ord for IdentityPropertyFormatKind
Sourcefn cmp(&self, other: &IdentityPropertyFormatKind) -> Ordering
fn cmp(&self, other: &IdentityPropertyFormatKind) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for IdentityPropertyFormatKind
impl PartialOrd for IdentityPropertyFormatKind
Sourceimpl Visit for IdentityPropertyFormatKind
impl Visit for IdentityPropertyFormatKind
Sourceimpl VisitMut for IdentityPropertyFormatKind
impl VisitMut for IdentityPropertyFormatKind
fn visit<V>(&mut self, visitor: &mut V) -> ControlFlow<<V as VisitorMut>::Break>where
V: VisitorMut,
impl Eq for IdentityPropertyFormatKind
impl StructuralPartialEq for IdentityPropertyFormatKind