Struct datafusion::datasource::listing::PartitionedFile
source · pub struct PartitionedFile {
pub object_meta: ObjectMeta,
pub partition_values: Vec<ScalarValue>,
pub range: Option<FileRange>,
pub extensions: Option<Arc<dyn Any + Send + Sync>>,
}Expand description
A single file or part of a file that should be read, along with its schema, statistics and partition column values that need to be appended to each row.
Fields
object_meta: ObjectMetaPath for the file (e.g. URL, filesystem path, etc)
partition_values: Vec<ScalarValue>Values of partition columns to be appended to each row.
These MUST have the same count, order, and type than the table_partition_cols.
You may use wrap_partition_value_in_dict to wrap them if you have used wrap_partition_type_in_dict to wrap the column type.
range: Option<FileRange>An optional file range for a more fine-grained parallel execution
extensions: Option<Arc<dyn Any + Send + Sync>>An optional field for user defined per object metadata
Implementations
sourceimpl PartitionedFile
impl PartitionedFile
sourcepub fn new(path: impl Into<String>, size: u64) -> Self
pub fn new(path: impl Into<String>, size: u64) -> Self
Create a simple file without metadata or partition
sourcepub fn new_with_range(path: String, size: u64, start: i64, end: i64) -> Self
pub fn new_with_range(path: String, size: u64, start: i64, end: i64) -> Self
Create a file range without metadata or partition
sourcepub fn with_range(self, start: i64, end: i64) -> Self
pub fn with_range(self, start: i64, end: i64) -> Self
Update the file to only scan the specified range (in bytes)