re-export of datafusion_physical_expr_adapter crate
Modules
- schema_
rewriter - Physical expression schema rewriting utilities:
PhysicalExprAdapter,PhysicalExprAdapterFactory, default implementations, andreplace_columns_with_literals.
Structs
- Batch
Adapter - Adapter for transforming record batches to match a target schema.
- Batch
Adapter Factory - Factory for creating
BatchAdapterinstances to adapt record batches to a target schema. - Default
Physical Expr Adapter - Default implementation of
PhysicalExprAdapterfor rewriting physical expressions to match different schemas. - Default
Physical Expr Adapter Factory
Traits
- Physical
Expr Adapter - Trait for adapting
PhysicalExprexpressions to match a target schema. - Physical
Expr Adapter Factory - Creates instances of
PhysicalExprAdapterfor given logical and physical schemas.
Functions
- replace_
columns_ with_ literals - Replace column references in the given physical expression with literal values.