Structs
- File
Pruner - Prune based on file-level statistics.
- Predicate
Rewriter - Rewrite a predicate expression in terms of statistics (min/max/null_counts)
for use as a
PruningPredicate. - Pruning
Predicate - Used to prove that arbitrary predicates (boolean expression) can not
possibly evaluate to
truegiven information about a column provided byPruningStatistics. - Pruning
Predicate Builder - Builder for a
PruningPredicate. Groups optional configuration —IN (...)rewrite cap, error counter — so future additions do not churn the top-level API. - Required
Columns - Describes which columns statistics are necessary to evaluate a
PruningPredicate.
Constants
- MAX_
IN_ LIST_ SIZE - Default maximum number of entries in an
IN (...)list that will be rewritten into a chain of per-value min/max checks bybuild_predicate_expression. Callers threading aPredicateRewritercan override this viaPredicateRewriter::with_max_in_list_size, and query engines can wire it from thedatafusion.execution.parquet.max_in_list_sizeconfig option.
Traits
- Pruning
Statistics - A source of runtime statistical information to
PruningPredicates. - Unhandled
Predicate Hook - Rewrites predicates that
PredicateRewritercan not handle, e.g. certain complex expressions or predicates that reference columns that are not in the schema.
Functions
- build_
pruning_ predicate - Build a pruning predicate from an optional predicate expression.
If the predicate is None or the predicate cannot be converted to a pruning
predicate, return None.
If there is an error creating the pruning predicate it is recorded by incrementing
the
predicate_creation_errorscounter.